Complete documentation with installation instruction, available at http://dolo.readthedocs.org/en/latest/
New in-progress [version](https://www.econforge.org/dolo.py).

Join the chat at https://gitter.im/EconForge/dolo

[![codecov](https://codecov.io/gh/EconForge/dolo.py/branch/master/graph/badge.svg?token=hLAd1OaTRp)](https://codecov.io/gh/EconForge/dolo.py)

![CI](https://github.com/EconForge/dolo.py/workflows/CI/badge.svg)

![Publish docs via GitHub Pages](https://github.com/EconForge/dolo.py/workflows/Publish%20docs%20via%20GitHub%20Pages/badge.svg)

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/EconForge/dolo.git/master?urlpath=lab)
